# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: AdminService.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import ErrorMessages_pb2 as ErrorMessages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x41\x64minService.proto\x12\x03xgt\x1a\x13\x45rrorMessages.proto\"#\n\x0bStringArray\x12\x14\n\x0cstring_value\x18\x01 \x03(\t\"p\n\x0b\x43onfigValue\x12\x14\n\nbool_value\x18\x01 \x01(\x08H\x00\x12\x13\n\tint_value\x18\x02 \x01(\x03H\x00\x12\x15\n\x0b\x66loat_value\x18\x03 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x04 \x01(\tH\x00\x42\x07\n\x05value\"D\n\x17\x43hangeErrorCountRequest\x12)\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32\x19.xgt.ErrorCountActionEnum\"J\n\x18\x43hangeErrorCountResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x13\n\x0b\x65rror_count\x18\x02 \x01(\x05\"\x1b\n\x19\x46reeUserMemorySizeRequest\"Q\n\x1a\x46reeUserMemorySizeResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x18\n\x10\x66ree_memory_size\x18\x02 \x01(\x03\"\x1a\n\x18MaxUserMemorySizeRequest\"I\n\x19MaxUserMemorySizeResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x11\n\tpool_size\x18\x02 \x01(\x03\" \n\x0fShutdownRequest\x12\r\n\x05\x66orce\x18\x01 \x01(\x08\"-\n\x10ShutdownResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\"\x10\n\x0eVersionRequest\"=\n\x0fVersionResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x0f\n\x07version\x18\x02 \x01(\t\":\n\x13\x41uthenticateRequest\x12\x13\n\x0b\x63redentials\x18\x01 \x01(\t\x12\x0e\n\x06userid\x18\x02 \x01(\t\"H\n\x14\x41uthenticateResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x15\n\rsession_token\x18\x02 \x01(\t\"G\n\x1bKerberosAuthenticateRequest\x12\x11\n\tkrb_token\x18\x01 \x01(\x0c\x12\x15\n\rsession_token\x18\x02 \x01(\t\"c\n\x1cKerberosAuthenticateResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x15\n\rsession_token\x18\x02 \x01(\t\x12\x11\n\tkrb_token\x18\x03 \x01(\x0c\"\x15\n\x13\x43loseSessionRequest\"1\n\x14\x43loseSessionResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\"\x1f\n\x10GetConfigRequest\x12\x0b\n\x03key\x18\x01 \x03(\t\"\xa6\x01\n\x11GetConfigResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x34\n\x07\x65ntries\x18\x02 \x03(\x0b\x32#.xgt.GetConfigResponse.EntriesEntry\x1a@\n\x0c\x45ntriesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.xgt.ConfigValue:\x02\x38\x01\"\x89\x01\n\x10SetConfigRequest\x12\x33\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\".xgt.SetConfigRequest.EntriesEntry\x1a@\n\x0c\x45ntriesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.xgt.ConfigValue:\x02\x38\x01\".\n\x11SetConfigResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\"7\n\x1aSetDefaultNamespaceRequest\x12\x19\n\x11\x64\x65\x66\x61ult_namespace\x18\x01 \x01(\t\"8\n\x1bSetDefaultNamespaceResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\"\x1c\n\x1aGetDefaultNamespaceRequest\"S\n\x1bGetDefaultNamespaceResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x19\n\x11\x64\x65\x66\x61ult_namespace\x18\x02 \x01(\t*T\n\x14\x45rrorCountActionEnum\x12\x1e\n\x1aUNKNOWN_ERROR_COUNT_ACTION\x10\x00\x12\r\n\tINCREMENT\x10\x01\x12\r\n\tDECREMENT\x10\x02\x32\xa4\x07\n\x0c\x41\x64minService\x12Q\n\x10\x43hangeErrorCount\x12\x1c.xgt.ChangeErrorCountRequest\x1a\x1d.xgt.ChangeErrorCountResponse\"\x00\x12W\n\x12\x46reeUserMemorySize\x12\x1e.xgt.FreeUserMemorySizeRequest\x1a\x1f.xgt.FreeUserMemorySizeResponse\"\x00\x12T\n\x11MaxUserMemorySize\x12\x1d.xgt.MaxUserMemorySizeRequest\x1a\x1e.xgt.MaxUserMemorySizeResponse\"\x00\x12\x39\n\x08Shutdown\x12\x14.xgt.ShutdownRequest\x1a\x15.xgt.ShutdownResponse\"\x00\x12\x36\n\x07Version\x12\x13.xgt.VersionRequest\x1a\x14.xgt.VersionResponse\"\x00\x12\x45\n\x0c\x41uthenticate\x12\x18.xgt.AuthenticateRequest\x1a\x19.xgt.AuthenticateResponse\"\x00\x12]\n\x14KerberosAuthenticate\x12 .xgt.KerberosAuthenticateRequest\x1a!.xgt.KerberosAuthenticateResponse\"\x00\x12\x45\n\x0c\x43loseSession\x12\x18.xgt.CloseSessionRequest\x1a\x19.xgt.CloseSessionResponse\"\x00\x12<\n\tGetConfig\x12\x15.xgt.GetConfigRequest\x1a\x16.xgt.GetConfigResponse\"\x00\x12<\n\tSetConfig\x12\x15.xgt.SetConfigRequest\x1a\x16.xgt.SetConfigResponse\"\x00\x12Z\n\x13SetDefaultNamespace\x12\x1f.xgt.SetDefaultNamespaceRequest\x1a .xgt.SetDefaultNamespaceResponse\"\x00\x12Z\n\x13GetDefaultNamespace\x12\x1f.xgt.GetDefaultNamespaceRequest\x1a .xgt.GetDefaultNamespaceResponse\"\x00\x62\x06proto3')

_ERRORCOUNTACTIONENUM = DESCRIPTOR.enum_types_by_name['ErrorCountActionEnum']
ErrorCountActionEnum = enum_type_wrapper.EnumTypeWrapper(_ERRORCOUNTACTIONENUM)
UNKNOWN_ERROR_COUNT_ACTION = 0
INCREMENT = 1
DECREMENT = 2


_STRINGARRAY = DESCRIPTOR.message_types_by_name['StringArray']
_CONFIGVALUE = DESCRIPTOR.message_types_by_name['ConfigValue']
_CHANGEERRORCOUNTREQUEST = DESCRIPTOR.message_types_by_name['ChangeErrorCountRequest']
_CHANGEERRORCOUNTRESPONSE = DESCRIPTOR.message_types_by_name['ChangeErrorCountResponse']
_FREEUSERMEMORYSIZEREQUEST = DESCRIPTOR.message_types_by_name['FreeUserMemorySizeRequest']
_FREEUSERMEMORYSIZERESPONSE = DESCRIPTOR.message_types_by_name['FreeUserMemorySizeResponse']
_MAXUSERMEMORYSIZEREQUEST = DESCRIPTOR.message_types_by_name['MaxUserMemorySizeRequest']
_MAXUSERMEMORYSIZERESPONSE = DESCRIPTOR.message_types_by_name['MaxUserMemorySizeResponse']
_SHUTDOWNREQUEST = DESCRIPTOR.message_types_by_name['ShutdownRequest']
_SHUTDOWNRESPONSE = DESCRIPTOR.message_types_by_name['ShutdownResponse']
_VERSIONREQUEST = DESCRIPTOR.message_types_by_name['VersionRequest']
_VERSIONRESPONSE = DESCRIPTOR.message_types_by_name['VersionResponse']
_AUTHENTICATEREQUEST = DESCRIPTOR.message_types_by_name['AuthenticateRequest']
_AUTHENTICATERESPONSE = DESCRIPTOR.message_types_by_name['AuthenticateResponse']
_KERBEROSAUTHENTICATEREQUEST = DESCRIPTOR.message_types_by_name['KerberosAuthenticateRequest']
_KERBEROSAUTHENTICATERESPONSE = DESCRIPTOR.message_types_by_name['KerberosAuthenticateResponse']
_CLOSESESSIONREQUEST = DESCRIPTOR.message_types_by_name['CloseSessionRequest']
_CLOSESESSIONRESPONSE = DESCRIPTOR.message_types_by_name['CloseSessionResponse']
_GETCONFIGREQUEST = DESCRIPTOR.message_types_by_name['GetConfigRequest']
_GETCONFIGRESPONSE = DESCRIPTOR.message_types_by_name['GetConfigResponse']
_GETCONFIGRESPONSE_ENTRIESENTRY = _GETCONFIGRESPONSE.nested_types_by_name['EntriesEntry']
_SETCONFIGREQUEST = DESCRIPTOR.message_types_by_name['SetConfigRequest']
_SETCONFIGREQUEST_ENTRIESENTRY = _SETCONFIGREQUEST.nested_types_by_name['EntriesEntry']
_SETCONFIGRESPONSE = DESCRIPTOR.message_types_by_name['SetConfigResponse']
_SETDEFAULTNAMESPACEREQUEST = DESCRIPTOR.message_types_by_name['SetDefaultNamespaceRequest']
_SETDEFAULTNAMESPACERESPONSE = DESCRIPTOR.message_types_by_name['SetDefaultNamespaceResponse']
_GETDEFAULTNAMESPACEREQUEST = DESCRIPTOR.message_types_by_name['GetDefaultNamespaceRequest']
_GETDEFAULTNAMESPACERESPONSE = DESCRIPTOR.message_types_by_name['GetDefaultNamespaceResponse']
StringArray = _reflection.GeneratedProtocolMessageType('StringArray', (_message.Message,), {
  'DESCRIPTOR' : _STRINGARRAY,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.StringArray)
  })
_sym_db.RegisterMessage(StringArray)

ConfigValue = _reflection.GeneratedProtocolMessageType('ConfigValue', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGVALUE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ConfigValue)
  })
_sym_db.RegisterMessage(ConfigValue)

ChangeErrorCountRequest = _reflection.GeneratedProtocolMessageType('ChangeErrorCountRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEERRORCOUNTREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ChangeErrorCountRequest)
  })
_sym_db.RegisterMessage(ChangeErrorCountRequest)

ChangeErrorCountResponse = _reflection.GeneratedProtocolMessageType('ChangeErrorCountResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEERRORCOUNTRESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ChangeErrorCountResponse)
  })
_sym_db.RegisterMessage(ChangeErrorCountResponse)

FreeUserMemorySizeRequest = _reflection.GeneratedProtocolMessageType('FreeUserMemorySizeRequest', (_message.Message,), {
  'DESCRIPTOR' : _FREEUSERMEMORYSIZEREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.FreeUserMemorySizeRequest)
  })
_sym_db.RegisterMessage(FreeUserMemorySizeRequest)

FreeUserMemorySizeResponse = _reflection.GeneratedProtocolMessageType('FreeUserMemorySizeResponse', (_message.Message,), {
  'DESCRIPTOR' : _FREEUSERMEMORYSIZERESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.FreeUserMemorySizeResponse)
  })
_sym_db.RegisterMessage(FreeUserMemorySizeResponse)

MaxUserMemorySizeRequest = _reflection.GeneratedProtocolMessageType('MaxUserMemorySizeRequest', (_message.Message,), {
  'DESCRIPTOR' : _MAXUSERMEMORYSIZEREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.MaxUserMemorySizeRequest)
  })
_sym_db.RegisterMessage(MaxUserMemorySizeRequest)

MaxUserMemorySizeResponse = _reflection.GeneratedProtocolMessageType('MaxUserMemorySizeResponse', (_message.Message,), {
  'DESCRIPTOR' : _MAXUSERMEMORYSIZERESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.MaxUserMemorySizeResponse)
  })
_sym_db.RegisterMessage(MaxUserMemorySizeResponse)

ShutdownRequest = _reflection.GeneratedProtocolMessageType('ShutdownRequest', (_message.Message,), {
  'DESCRIPTOR' : _SHUTDOWNREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ShutdownRequest)
  })
_sym_db.RegisterMessage(ShutdownRequest)

ShutdownResponse = _reflection.GeneratedProtocolMessageType('ShutdownResponse', (_message.Message,), {
  'DESCRIPTOR' : _SHUTDOWNRESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ShutdownResponse)
  })
_sym_db.RegisterMessage(ShutdownResponse)

VersionRequest = _reflection.GeneratedProtocolMessageType('VersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.VersionRequest)
  })
_sym_db.RegisterMessage(VersionRequest)

VersionResponse = _reflection.GeneratedProtocolMessageType('VersionResponse', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONRESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.VersionResponse)
  })
_sym_db.RegisterMessage(VersionResponse)

AuthenticateRequest = _reflection.GeneratedProtocolMessageType('AuthenticateRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATEREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.AuthenticateRequest)
  })
_sym_db.RegisterMessage(AuthenticateRequest)

AuthenticateResponse = _reflection.GeneratedProtocolMessageType('AuthenticateResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATERESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.AuthenticateResponse)
  })
_sym_db.RegisterMessage(AuthenticateResponse)

KerberosAuthenticateRequest = _reflection.GeneratedProtocolMessageType('KerberosAuthenticateRequest', (_message.Message,), {
  'DESCRIPTOR' : _KERBEROSAUTHENTICATEREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.KerberosAuthenticateRequest)
  })
_sym_db.RegisterMessage(KerberosAuthenticateRequest)

KerberosAuthenticateResponse = _reflection.GeneratedProtocolMessageType('KerberosAuthenticateResponse', (_message.Message,), {
  'DESCRIPTOR' : _KERBEROSAUTHENTICATERESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.KerberosAuthenticateResponse)
  })
_sym_db.RegisterMessage(KerberosAuthenticateResponse)

CloseSessionRequest = _reflection.GeneratedProtocolMessageType('CloseSessionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLOSESESSIONREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.CloseSessionRequest)
  })
_sym_db.RegisterMessage(CloseSessionRequest)

CloseSessionResponse = _reflection.GeneratedProtocolMessageType('CloseSessionResponse', (_message.Message,), {
  'DESCRIPTOR' : _CLOSESESSIONRESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.CloseSessionResponse)
  })
_sym_db.RegisterMessage(CloseSessionResponse)

GetConfigRequest = _reflection.GeneratedProtocolMessageType('GetConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.GetConfigRequest)
  })
_sym_db.RegisterMessage(GetConfigRequest)

GetConfigResponse = _reflection.GeneratedProtocolMessageType('GetConfigResponse', (_message.Message,), {

  'EntriesEntry' : _reflection.GeneratedProtocolMessageType('EntriesEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETCONFIGRESPONSE_ENTRIESENTRY,
    '__module__' : 'AdminService_pb2'
    # @@protoc_insertion_point(class_scope:xgt.GetConfigResponse.EntriesEntry)
    })
  ,
  'DESCRIPTOR' : _GETCONFIGRESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.GetConfigResponse)
  })
_sym_db.RegisterMessage(GetConfigResponse)
_sym_db.RegisterMessage(GetConfigResponse.EntriesEntry)

SetConfigRequest = _reflection.GeneratedProtocolMessageType('SetConfigRequest', (_message.Message,), {

  'EntriesEntry' : _reflection.GeneratedProtocolMessageType('EntriesEntry', (_message.Message,), {
    'DESCRIPTOR' : _SETCONFIGREQUEST_ENTRIESENTRY,
    '__module__' : 'AdminService_pb2'
    # @@protoc_insertion_point(class_scope:xgt.SetConfigRequest.EntriesEntry)
    })
  ,
  'DESCRIPTOR' : _SETCONFIGREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.SetConfigRequest)
  })
_sym_db.RegisterMessage(SetConfigRequest)
_sym_db.RegisterMessage(SetConfigRequest.EntriesEntry)

SetConfigResponse = _reflection.GeneratedProtocolMessageType('SetConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIGRESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.SetConfigResponse)
  })
_sym_db.RegisterMessage(SetConfigResponse)

SetDefaultNamespaceRequest = _reflection.GeneratedProtocolMessageType('SetDefaultNamespaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETDEFAULTNAMESPACEREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.SetDefaultNamespaceRequest)
  })
_sym_db.RegisterMessage(SetDefaultNamespaceRequest)

SetDefaultNamespaceResponse = _reflection.GeneratedProtocolMessageType('SetDefaultNamespaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETDEFAULTNAMESPACERESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.SetDefaultNamespaceResponse)
  })
_sym_db.RegisterMessage(SetDefaultNamespaceResponse)

GetDefaultNamespaceRequest = _reflection.GeneratedProtocolMessageType('GetDefaultNamespaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDEFAULTNAMESPACEREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.GetDefaultNamespaceRequest)
  })
_sym_db.RegisterMessage(GetDefaultNamespaceRequest)

GetDefaultNamespaceResponse = _reflection.GeneratedProtocolMessageType('GetDefaultNamespaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDEFAULTNAMESPACERESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.GetDefaultNamespaceResponse)
  })
_sym_db.RegisterMessage(GetDefaultNamespaceResponse)

_ADMINSERVICE = DESCRIPTOR.services_by_name['AdminService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETCONFIGRESPONSE_ENTRIESENTRY._options = None
  _GETCONFIGRESPONSE_ENTRIESENTRY._serialized_options = b'8\001'
  _SETCONFIGREQUEST_ENTRIESENTRY._options = None
  _SETCONFIGREQUEST_ENTRIESENTRY._serialized_options = b'8\001'
  _ERRORCOUNTACTIONENUM._serialized_start=1724
  _ERRORCOUNTACTIONENUM._serialized_end=1808
  _STRINGARRAY._serialized_start=48
  _STRINGARRAY._serialized_end=83
  _CONFIGVALUE._serialized_start=85
  _CONFIGVALUE._serialized_end=197
  _CHANGEERRORCOUNTREQUEST._serialized_start=199
  _CHANGEERRORCOUNTREQUEST._serialized_end=267
  _CHANGEERRORCOUNTRESPONSE._serialized_start=269
  _CHANGEERRORCOUNTRESPONSE._serialized_end=343
  _FREEUSERMEMORYSIZEREQUEST._serialized_start=345
  _FREEUSERMEMORYSIZEREQUEST._serialized_end=372
  _FREEUSERMEMORYSIZERESPONSE._serialized_start=374
  _FREEUSERMEMORYSIZERESPONSE._serialized_end=455
  _MAXUSERMEMORYSIZEREQUEST._serialized_start=457
  _MAXUSERMEMORYSIZEREQUEST._serialized_end=483
  _MAXUSERMEMORYSIZERESPONSE._serialized_start=485
  _MAXUSERMEMORYSIZERESPONSE._serialized_end=558
  _SHUTDOWNREQUEST._serialized_start=560
  _SHUTDOWNREQUEST._serialized_end=592
  _SHUTDOWNRESPONSE._serialized_start=594
  _SHUTDOWNRESPONSE._serialized_end=639
  _VERSIONREQUEST._serialized_start=641
  _VERSIONREQUEST._serialized_end=657
  _VERSIONRESPONSE._serialized_start=659
  _VERSIONRESPONSE._serialized_end=720
  _AUTHENTICATEREQUEST._serialized_start=722
  _AUTHENTICATEREQUEST._serialized_end=780
  _AUTHENTICATERESPONSE._serialized_start=782
  _AUTHENTICATERESPONSE._serialized_end=854
  _KERBEROSAUTHENTICATEREQUEST._serialized_start=856
  _KERBEROSAUTHENTICATEREQUEST._serialized_end=927
  _KERBEROSAUTHENTICATERESPONSE._serialized_start=929
  _KERBEROSAUTHENTICATERESPONSE._serialized_end=1028
  _CLOSESESSIONREQUEST._serialized_start=1030
  _CLOSESESSIONREQUEST._serialized_end=1051
  _CLOSESESSIONRESPONSE._serialized_start=1053
  _CLOSESESSIONRESPONSE._serialized_end=1102
  _GETCONFIGREQUEST._serialized_start=1104
  _GETCONFIGREQUEST._serialized_end=1135
  _GETCONFIGRESPONSE._serialized_start=1138
  _GETCONFIGRESPONSE._serialized_end=1304
  _GETCONFIGRESPONSE_ENTRIESENTRY._serialized_start=1240
  _GETCONFIGRESPONSE_ENTRIESENTRY._serialized_end=1304
  _SETCONFIGREQUEST._serialized_start=1307
  _SETCONFIGREQUEST._serialized_end=1444
  _SETCONFIGREQUEST_ENTRIESENTRY._serialized_start=1240
  _SETCONFIGREQUEST_ENTRIESENTRY._serialized_end=1304
  _SETCONFIGRESPONSE._serialized_start=1446
  _SETCONFIGRESPONSE._serialized_end=1492
  _SETDEFAULTNAMESPACEREQUEST._serialized_start=1494
  _SETDEFAULTNAMESPACEREQUEST._serialized_end=1549
  _SETDEFAULTNAMESPACERESPONSE._serialized_start=1551
  _SETDEFAULTNAMESPACERESPONSE._serialized_end=1607
  _GETDEFAULTNAMESPACEREQUEST._serialized_start=1609
  _GETDEFAULTNAMESPACEREQUEST._serialized_end=1637
  _GETDEFAULTNAMESPACERESPONSE._serialized_start=1639
  _GETDEFAULTNAMESPACERESPONSE._serialized_end=1722
  _ADMINSERVICE._serialized_start=1811
  _ADMINSERVICE._serialized_end=2743
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: MetricsService.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import ErrorMessages_pb2 as ErrorMessages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14MetricsService.proto\x12\x03xgt\x1a\x13\x45rrorMessages.proto\"\x16\n\x14MetricsStatusRequest\"Z\n\x15MetricsStatusResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12&\n\x06status\x18\x02 \x01(\x0e\x32\x16.xgt.MetricsStatusEnum\"\x15\n\x13\x43learMetricsRequest\"1\n\x14\x43learMetricsResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error*l\n\x11MetricsStatusEnum\x12\x1a\n\x16UNKNOWN_METRICS_STATUS\x10\x00\x12\x15\n\x11METRICS_COMPLETED\x10\x01\x12\x13\n\x0fMETRICS_RUNNING\x10\x02\x12\x0f\n\x0bMETRICS_OFF\x10\x03\x32\xa4\x01\n\x0eMetricsService\x12K\n\x10GetMetricsStatus\x12\x19.xgt.MetricsStatusRequest\x1a\x1a.xgt.MetricsStatusResponse\"\x00\x12\x45\n\x0c\x43learMetrics\x12\x18.xgt.ClearMetricsRequest\x1a\x19.xgt.ClearMetricsResponse\"\x00\x62\x06proto3')

_METRICSSTATUSENUM = DESCRIPTOR.enum_types_by_name['MetricsStatusEnum']
MetricsStatusEnum = enum_type_wrapper.EnumTypeWrapper(_METRICSSTATUSENUM)
UNKNOWN_METRICS_STATUS = 0
METRICS_COMPLETED = 1
METRICS_RUNNING = 2
METRICS_OFF = 3


_METRICSSTATUSREQUEST = DESCRIPTOR.message_types_by_name['MetricsStatusRequest']
_METRICSSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['MetricsStatusResponse']
_CLEARMETRICSREQUEST = DESCRIPTOR.message_types_by_name['ClearMetricsRequest']
_CLEARMETRICSRESPONSE = DESCRIPTOR.message_types_by_name['ClearMetricsResponse']
MetricsStatusRequest = _reflection.GeneratedProtocolMessageType('MetricsStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _METRICSSTATUSREQUEST,
  '__module__' : 'MetricsService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.MetricsStatusRequest)
  })
_sym_db.RegisterMessage(MetricsStatusRequest)

MetricsStatusResponse = _reflection.GeneratedProtocolMessageType('MetricsStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _METRICSSTATUSRESPONSE,
  '__module__' : 'MetricsService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.MetricsStatusResponse)
  })
_sym_db.RegisterMessage(MetricsStatusResponse)

ClearMetricsRequest = _reflection.GeneratedProtocolMessageType('ClearMetricsRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLEARMETRICSREQUEST,
  '__module__' : 'MetricsService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ClearMetricsRequest)
  })
_sym_db.RegisterMessage(ClearMetricsRequest)

ClearMetricsResponse = _reflection.GeneratedProtocolMessageType('ClearMetricsResponse', (_message.Message,), {
  'DESCRIPTOR' : _CLEARMETRICSRESPONSE,
  '__module__' : 'MetricsService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ClearMetricsResponse)
  })
_sym_db.RegisterMessage(ClearMetricsResponse)

_METRICSSERVICE = DESCRIPTOR.services_by_name['MetricsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _METRICSSTATUSENUM._serialized_start=240
  _METRICSSTATUSENUM._serialized_end=348
  _METRICSSTATUSREQUEST._serialized_start=50
  _METRICSSTATUSREQUEST._serialized_end=72
  _METRICSSTATUSRESPONSE._serialized_start=74
  _METRICSSTATUSRESPONSE._serialized_end=164
  _CLEARMETRICSREQUEST._serialized_start=166
  _CLEARMETRICSREQUEST._serialized_end=187
  _CLEARMETRICSRESPONSE._serialized_start=189
  _CLEARMETRICSRESPONSE._serialized_end=238
  _METRICSSERVICE._serialized_start=351
  _METRICSSERVICE._serialized_end=515
# @@protoc_insertion_point(module_scope)
